@@ -425,28 +425,36 @@ class PorterStemmer(StemmerI):
             word, [("ll", "l", lambda stem: self._measure(word[:-1]) > 1)]
         )
 
-    def stem(self, word, to_lowercase=True):
+    def stem(self, sentence, to_lowercase=True):
         """
         :param to_lowercase: if `to_lowercase=True` the word always lowercase
         """
-        stem = word.lower() if to_lowercase else word
+        words = sentence.split()
+        stemmed_sentence = []
+        for word in words:
+            stem = word.lower() if to_lowercase else word
 
-        if self.mode == self.STEM_EXTENSION and word in self.pool:
-            return self.pool[stem]
+            if self.mode == self.STEM_EXTENSION and word in self.pool:
+                return self.pool[stem]
 
-        if len(word) <= 2:
-            return stem
+            if len(word) <= 2:
+                stemmed_sentence.append(stem)
 
-        stem = self._step1a(stem)
-        stem = self._step1b(stem)
-        stem = self._step1c(stem)
-        stem = self._step2(stem)
-        stem = self._step3(stem)
-        stem = self._step4(stem)
-        stem = self._step5a(stem)
-        stem = self._step5b(stem)
+            else:
+                stem = self._step1a(stem)
+                stem = self._step1b(stem)
+                stem = self._step1c(stem)
+                stem = self._step2(stem)
+                stem = self._step3(stem)
+                stem = self._step4(stem)
+                stem = self._step5a(stem)
+                stem = self._step5b(stem)
 
-        return stem
+                stemmed_sentence.append(stem)
+    
+        str_stemmed_sentence = " ".join(stemmed_sentence)
+
+        return str_stemmed_sentence
 
     def __repr__(self):
         return "<PorterStemmer>"
